@@ -23,8 +23,8 @@ except ImportError:
     JSONDecodeError = ValueError
 from yaml.parser import ParserError, ScannerError
 from yaml import YAMLError
-import cfnlint.decode.cfn_yaml
-import cfnlint.decode.cfn_json
+from cfnlint.decode import cfn_yaml, cfn_json
+from cfnlint.rules import Match, ParseError
 
 
 LOGGER = logging.getLogger(__name__)
@@ -37,24 +37,32 @@ def decode(filename, ignore_bad_template):
     template = None
     matches = []
     try:
-        template = cfnlint.decode.cfn_yaml.load(filename)
+        template = cfn_yaml.load(filename)
     except IOError as e:
         if e.errno == 2:
             LOGGER.error('Template file not found: %s', filename)
-            matches.append(create_match_file_error(filename, 'Template file not found: %s' % filename))
+            matches.append(create_match_file_error(
+                filename, 'Template file not found: %s' % filename))
         elif e.errno == 21:
-            LOGGER.error('Template references a directory, not a file: %s', filename)
-            matches.append(create_match_file_error(filename, 'Template references a directory, not a file: %s' % filename))
+            LOGGER.error('Template references a directory, not a file: %s',
+                         filename)
+            matches.append(create_match_file_error(
+                filename,
+                'Template references a directory, not a file: %s' % filename))
         elif e.errno == 13:
-            LOGGER.error('Permission denied when accessing template file: %s', filename)
-            matches.append(create_match_file_error(filename, 'Permission denied when accessing template file: %s' % filename))
+            LOGGER.error('Permission denied when accessing template file: %s',
+                         filename)
+            matches.append(create_match_file_error(
+                filename,
+                'Permission denied when accessing template file: %s' % filename))
 
         if matches:
             return(None, matches)
     except UnicodeDecodeError as err:
         LOGGER.error('Cannot read file contents: %s', filename)
-        matches.append(create_match_file_error(filename, 'Cannot read file contents: %s' % filename))
-    except cfnlint.decode.cfn_yaml.CfnParseError as err:
+        matches.append(create_match_file_error(
+            filename, 'Cannot read file contents: %s' % filename))
+    except cfn_yaml.CfnParseError as err:
         err.match.Filename = filename
         matches = [err.match]
     except ParserError as err:
@@ -64,20 +72,27 @@ def decode(filename, ignore_bad_template):
                 'found character \'\\t\' that cannot start any token',
                 'found unknown escape character']:
             try:
-                template = cfnlint.decode.cfn_json.load(filename)
-            except cfnlint.decode.cfn_json.JSONDecodeError as json_err:
+                template = cfn_json.load(filename)
+            except cfn_json.JSONDecodeError as json_err:
                 json_err.match.filename = filename
                 matches = [json_err.match]
             except JSONDecodeError as json_err:
                 matches = [create_match_json_parser_error(json_err, filename)]
             except Exception as json_err:  # pylint: disable=W0703
                 if ignore_bad_template:
-                    LOGGER.info('Template %s is malformed: %s', filename, err.problem)
-                    LOGGER.info('Tried to parse %s as JSON but got error: %s', filename, str(json_err))
+                    LOGGER.info('Template %s is malformed: %s',
+                                filename, err.problem)
+                    LOGGER.info('Tried to parse %s as JSON but got error: %s',
+                                filename, str(json_err))
                 else:
-                    LOGGER.error('Template %s is malformed: %s', filename, err.problem)
-                    LOGGER.error('Tried to parse %s as JSON but got error: %s', filename, str(json_err))
-                    return(None, [create_match_file_error(filename, 'Tried to parse %s as JSON but got error: %s' % (filename, str(json_err)))])
+                    LOGGER.error(
+                        'Template %s is malformed: %s', filename, err.problem)
+                    LOGGER.error('Tried to parse %s as JSON but got error: %s',
+                                 filename, str(json_err))
+                    return (None, [create_match_file_error(
+                        filename,
+                        'Tried to parse %s as JSON but got error: %s' % (
+                            filename, str(json_err)))])
         else:
             matches = [create_match_yaml_parser_error(err, filename)]
     except YAMLError as err:
@@ -85,7 +100,8 @@ def decode(filename, ignore_bad_template):
 
     if not isinstance(template, dict) and not matches:
         # Template isn't a dict which means nearly nothing will work
-        matches = [cfnlint.Match(1, 1, 1, 1, filename, cfnlint.ParseError(), message='Template needs to be an object.')]
+        matches = [Match(1, 1, 1, 1, filename, ParseError(),
+                         message='Template needs to be an object.')]
     return (template, matches)
 
 
@@ -94,16 +110,16 @@ def create_match_yaml_parser_error(parser_error, filename):
     lineno = parser_error.problem_mark.line + 1
     colno = parser_error.problem_mark.column + 1
     msg = parser_error.problem
-    return cfnlint.Match(
+    return Match(
         lineno, colno, lineno, colno + 1, filename,
-        cfnlint.ParseError(), message=msg)
+        ParseError(), message=msg)
 
 
 def create_match_file_error(filename, msg):
     """Create a Match for a parser error"""
-    return cfnlint.Match(
+    return Match(
         linenumber=1, columnnumber=1, linenumberend=1, columnnumberend=2,
-        filename=filename, rule=cfnlint.ParseError(), message=msg)
+        filename=filename, rule=ParseError(), message=msg)
 
 
 def create_match_json_parser_error(parser_error, filename):
@@ -116,5 +132,5 @@ def create_match_json_parser_error(parser_error, filename):
         lineno = 1
         colno = 1
         msg = parser_error.message
-    return cfnlint.Match(
-        lineno, colno, lineno, colno + 1, filename, cfnlint.ParseError(), message=msg)
+    return Match(
+        lineno, colno, lineno, colno + 1, filename, ParseError(), message=msg)
